summaryrefslogtreecommitdiff
path: root/xstatic/pkg/jquery_ui/data/ui/jquery.ui.droppable.js
diff options
context:
space:
mode:
Diffstat (limited to 'xstatic/pkg/jquery_ui/data/ui/jquery.ui.droppable.js')
-rw-r--r--xstatic/pkg/jquery_ui/data/ui/jquery.ui.droppable.js15
1 files changed, 10 insertions, 5 deletions
diff --git a/xstatic/pkg/jquery_ui/data/ui/jquery.ui.droppable.js b/xstatic/pkg/jquery_ui/data/ui/jquery.ui.droppable.js
index afd421f..f17c222 100644
--- a/xstatic/pkg/jquery_ui/data/ui/jquery.ui.droppable.js
+++ b/xstatic/pkg/jquery_ui/data/ui/jquery.ui.droppable.js
@@ -1,7 +1,7 @@
/*
* jQuery UI Droppable 1.8.18
*
- * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2012, AUTHORS.txt (http://jqueryui.com/about)
* Dual licensed under the MIT or GPL Version 2 licenses.
* http://jquery.org/license
*
@@ -147,7 +147,7 @@ $.widget("ui.droppable", {
});
$.extend($.ui.droppable, {
- version: "1.8.18"
+ version: "1.8.24"
});
$.ui.intersect = function(draggable, droppable, toleranceMode) {
@@ -260,7 +260,12 @@ $.ui.ddmanager = {
var parentInstance;
if (this.options.greedy) {
- var parent = this.element.parents(':data(droppable):eq(0)');
+ // find droppable parents with same scope
+ var scope = this.options.scope;
+ var parent = this.element.parents(':data(droppable)').filter(function () {
+ return $.data(this, 'droppable').options.scope === scope;
+ });
+
if (parent.length) {
parentInstance = $.data(parent[0], 'droppable');
parentInstance.greedyChild = (c == 'isover' ? 1 : 0);
@@ -1,7 +1,7 @@
-/*
- * jQuery UI Droppable 1.8.18
+/*!
+ * jQuery UI Droppable 1.8.24
*